/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.farm;

import java.awt.Dialog;
import java.awt.Image;
import java.awt.event.ActionEvent;
import java.io.IOException;
import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JOptionPane;
import org.netbeans.spi.project.ui.support.CommonProjectActions;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;

/**
 * This is the node you actually see in the project tab for the project
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
@NbBundle.Messages({"action.new_fieldplan.message=New Field Plan"})
final class FarmNode extends FilterNode {
    private final FarmProject project;
    private final Node farmFileNode;

    public FarmNode(Node farmFileNode, Node projectFolderNode, FarmProject project) throws DataObjectNotFoundException {
                    super(projectFolderNode, 
//                            new FilterNode.Children(projectFolderNode),
                            NodeFactorySupport.createCompositeChildren(project, "Projects/nl-cloudfarming-client-farm/Nodes"),
        //                    //The projects system wants the project in the Node's lookup.
        //                    //NewAction and friends want the original Node's lookup.
        //                    //Make a merge of both
                            new ProxyLookup(new Lookup[]{Lookups.singleton(project),
                                farmFileNode.getLookup()
                            }));
        this.farmFileNode= farmFileNode;
        this.project = project;
    }

    @Override
    public Action[] getActions(boolean arg0) {
        Action[] nodeActions = new Action[5];
        //            nodeActions[0] = CommonProjectActions.newFileAction();
        //            nodeActions[1] = CommonProjectActions.copyProjectAction();
        //            nodeActions[3] = CommonProjectActions.newProjectAction();
        //            nodeActions[4] = CommonProjectActions.openSubprojectsAction();
        nodeActions[0] = CommonProjectActions.setAsMainProjectAction();
        nodeActions[1] = CommonProjectActions.closeProjectAction();
        nodeActions[2] = farmFileNode.getPreferredAction();
        nodeActions[3] = new NewFieldPlanAction(project);
        nodeActions[4] = new RemoveFarmAction(project);
        return nodeActions;
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(FarmProjectFactory.ICON);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }

    @Override
    public String getDisplayName() {
        return project.getProjectDirectory().getName();
    }
    
    private final class RemoveFarmAction extends AbstractAction{
        
        private FarmProject project;
        private static final String TITLE = "Delete";   

        public RemoveFarmAction(FarmProject project){
            putValue(NAME, TITLE);
            this.project = project;
        }    

        @Override
        public void actionPerformed(ActionEvent e) {
            // TODO: Would this be a correct way to remove a Farm?
            
            int option = JOptionPane.showConfirmDialog(
                    null,
                    "Are you sure you want to delete the farm " + project.getFarm().getName() + "?",
                    "Warning!",
                    JOptionPane.YES_NO_OPTION);
           
            if(option == 0){ // YES
                CommonProjectActions.closeProjectAction().actionPerformed(null);
                try {
                    project.getProjectDirectory().delete();
                } catch (IOException ex) {
                    Exceptions.printStackTrace(ex);
                }
            }
            
        }

    }
}
