/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.farm;

import java.io.IOException;
import nl.cloudfarming.client.farm.model.Farm;
import nl.cloudfarming.client.farm.model.FarmManager;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ProjectFactory;
import org.netbeans.spi.project.ProjectState;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;

/**
 *
 * @author Timon Veenstra
 */
@org.openide.util.lookup.ServiceProvider(service = ProjectFactory.class)
public class FarmProjectFactory implements ProjectFactory {

    public static final String ICON = "nl/cloudfarming/client/farm/house.png";
    public static final String FARM_FILE = "farm.frm";

    //Specifies when a project is a project, i.e.,
    //if farm binary file is present:
    @Override
    public boolean isProject(FileObject projectDirectory) {
        return projectDirectory.getFileObject(FARM_FILE) != null;
    }

    //Specifies when the project will be opened, i.e.,
    //if the project exists:
    @Override
    public Project loadProject(FileObject dir, ProjectState state) throws IOException {
        FarmProject project = null;
        if (isProject(dir)) {
            FarmManager farmManager = Lookup.getDefault().lookup(FarmManager.class);
            Farm farm = farmManager.load(dir.getFileObject(FARM_FILE));
            project = new FarmProject(dir, state, farm);
        }
        return project;
    }

    @Override
    public void saveProject(final Project project) throws IOException, ClassCastException {
        FileObject projectRoot = project.getProjectDirectory();
        FarmManager farmManager = Lookup.getDefault().lookup(FarmManager.class);
        Farm farm = project.getLookup().lookup(Farm.class);
        farmManager.save(farm, projectRoot.createData(FARM_FILE));
    }
}
